Description Usage Arguments Details Value Examples
Returns a report containing D18, S2, and H20 IBIs, along with relevant QC metrics
1 | algae.IBIs(data, metadata = NULL)
|
data |
A data frame containing necessary algae data. See details |
metadata |
A data frame contain taxonomic lookup data. If null (default), uses metadata distributed with this package |
To be valid, your data should contain the following columns:
StationCode: The name of the site where the sample was taken
SampleDate: Date the sample was taken
Replicate: Identifier for multiple samples at a given site
SampleTypeCode: Acceptable values: Epiphyte, Macroalgae, Microalgae, Qualitative
FinalID: Taxa names. These names must match exactly with a FinalID in the metadata, or the row will be discarded
BAResult: Results for Integrated and Epiphyte fractions
Result: Results for Macro/Microalgae algae
ActualOrganismCount: Sample-wide count
A SampleID column, while not required, is strongly encouraged. If missing, it will be generated as a concatenation of columns StationCode, SampleDate, and Replicate.
A data frame containing the following:
SampleID
S2: S2 soft algae IBI score
S2.QCmin: Lowest QC score among metrics used in S2
D18: D18 diatom IBI score
D18.QCmin: Lowest QC score among metrics used in D18
DH20: H20 hybrid (soft algae and diatom) IBI score
DH20.QCmin: Lowest QC score among metrics used in DH20
DiatomSamplePresent: Indicates whether diatom count was non-zero
SoftAlgaeSampleTypesPresent: List of fractions present in sample
QualPresent: Indicates whether qualitative fraction was present
DiatomCountFlag: Flags for low diatom count (threshold of 450)
SoftAlgaeEntityCountFlag: Flags for low entity count (threshold of 225)
PurgedTaxa: Number of rows discarded due to FinalID not matching any entry in metadata
1 2 | data(algaeSamples)
ibiReport <- algae.IBIs(algaeSamples)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.