taxonInfo: Algae taxon validation

Description Usage Arguments Value Examples

View source: R/taxonCheck.r

Description

Checks that all FinalIDs are present in metadata. If not, the row is purged. Remainder are then merged together with metadata.

Usage

1
taxonInfo(data, algaeMetaData = NULL)

Arguments

data

A validated algae data frame

algaeMetaData

A data frame contain taxonomic lookup data. If null (default), uses metadata distributed with this package

Value

A list containing the cleaned data, a report of the number rows purged per sample, a table listing all taxa in all samples, and whether it was present in the metadata.

Examples

1
2
3
data(algaeSamples)
tinfo <- taxonInfo(validator(algaeSamples))
tinfo$taxaSummary

SCCWRP/algaeMetrics documentation built on Oct. 27, 2021, 2:29 a.m.