Description Usage Arguments Value Examples
Checks that all FinalIDs are present in metadata. If not, the row is purged. Remainder are then merged together with metadata.
1 |
data |
A validated algae data frame |
algaeMetaData |
A data frame contain taxonomic lookup data. If null (default), uses metadata distributed with this package |
A list containing the cleaned data, a report of the number rows purged per sample, a table listing all taxa in all samples, and whether it was present in the metadata.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.